@@ -79,8 +79,16 @@ var dav = {
                 if (folders.length == 1) {
                     switch (aName) {
                         case "color":
+                            //prepare connection data
+                            let connection = {};
+                            connection.account = folders[0].account;
+                            connection.folderID = folders[0].folderID;
+                            connection.type = "cal";
+                            connection.fqdn = folders[0].fqdn;
+                            dav.tools.addAccountDataToConnectionData(connection);
+
                             //update stored color to recover after disable
-                            dav.tools.sendRequest("<d:propertyupdate "+dav.tools.xmlns(["d","apple"])+"><d:set><d:prop><apple:calendar-color>"+(aValue + "FFFFFFFF").slice(0,9)+"</apple:calendar-color></d:prop></d:set></d:propertyupdate>", folders[0].folderID, "PROPPATCH", {account: folders[0].account, fqdn: folders[0].fqdn});
+                            dav.tools.sendRequest("<d:propertyupdate "+dav.tools.xmlns(["d","apple"])+"><d:set><d:prop><apple:calendar-color>"+(aValue + "FFFFFFFF").slice(0,9)+"</apple:calendar-color></d:prop></d:set></d:propertyupdate>", folders[0].folderID, "PROPPATCH", connection);
                             break;
                     }
                 }
@@ -140,10 +148,14 @@ var dav = {
      */
     load: Task.async (function* (lightningIsAvail) {
         //load overlays or do other init stuff, use lightningIsAvail to init stuff if lightning is installed
-        yield tbSync.overlayManager.registerOverlay("chrome://messenger/content/addressbook/abEditCardDialog.xul", "chrome://dav4tbsync/content/overlays/abCardWindow.xul");
-        yield tbSync.overlayManager.registerOverlay("chrome://messenger/content/addressbook/abNewCardDialog.xul", "chrome://dav4tbsync/content/overlays/abCardWindow.xul");
-        yield tbSync.overlayManager.registerOverlay("chrome://messenger/content/addressbook/addressbook.xul", "chrome://dav4tbsync/content/overlays/addressbookoverlay.xul");
-
+        dav.overlayManager = new OverlayManager({verbose: 0});
+        yield dav.overlayManager.registerOverlay("chrome://messenger/content/addressbook/abNewCardDialog.xul", "chrome://dav4tbsync/content/overlays/abNewCardWindow.xul");
+        yield dav.overlayManager.registerOverlay("chrome://messenger/content/addressbook/abNewCardDialog.xul", "chrome://dav4tbsync/content/overlays/abCardWindow.xul");
+        yield dav.overlayManager.registerOverlay("chrome://messenger/content/addressbook/abEditCardDialog.xul", "chrome://dav4tbsync/content/overlays/abCardWindow.xul");
+        yield dav.overlayManager.registerOverlay("chrome://messenger/content/addressbook/addressbook.xul", "chrome://dav4tbsync/content/overlays/addressbookoverlay.xul");
+        yield dav.overlayManager.registerOverlay("chrome://messenger/content/addressbook/addressbook.xul", "chrome://dav4tbsync/content/overlays/addressbookdetailsoverlay.xul");
+        dav.overlayManager.startObserving();
+	
         if (lightningIsAvail) {
             cal.getCalendarManager().addObserver(tbSync.dav.calendarManagerObserver);    
             cal.getCalendarManager().addCalendarObserver(tbSync.dav.calendarObserver);            
@@ -187,7 +199,8 @@ var dav = {
         if (lightningIsAvail) {
             cal.getCalendarManager().removeObserver(tbSync.dav.calendarManagerObserver);
             cal.getCalendarManager().removeCalendarObserver(tbSync.dav.calendarObserver);                        
-        }        
+        }
+        dav.overlayManager.stopObserving();	
     },
 
 
@@ -231,7 +244,7 @@ var dav = {
         if (accountId !== null) {
             let serviceprovider = tbSync.db.getAccountSetting(accountId, "serviceprovider");
             if (tbSync.dav.serviceproviders.hasOwnProperty(serviceprovider)) {
-                base =  tbSync.dav.serviceproviders[serviceprovider].icon;
+                base = tbSync.dav.serviceproviders[serviceprovider].icon;
             }
         }
         
@@ -316,7 +329,6 @@ var dav = {
             "createdWithProviderVersion" : "0",
 
             "syncGroups" : "0",
-            "useHomeAsPrimary" : "0",
             "useCache" : "1",
             "useCardBook" : "0",
             }; 
@@ -336,7 +348,6 @@ var dav = {
             //so we need to store the fqdn information per folders
             "fqdn" : "",
 
-            "url" : "",
             "name" : "",
             "type" : "", //cladav, carddav or ics
             "shared": "", //identify shared resources
@@ -438,7 +449,17 @@ var dav = {
         //This example implementation is using the standard address book, but you may use another one
         let abManager = Components.classes["@mozilla.org/abmanager;1"].getService(Components.interfaces.nsIAbManager);
 
-        return abManager.newAddressBook(newname, "", 2);
+        let dirPrefId = abManager.newAddressBook(newname, "", 2);
+        let data = abManager.getDirectoryFromId(dirPrefId);
+        if (data instanceof Components.interfaces.nsIAbDirectory && data.dirPrefId == dirPrefId) {
+            let serviceprovider = tbSync.db.getAccountSetting(account, "serviceprovider");
+            let icon = "custom";
+            if (dav.serviceproviders.hasOwnProperty(serviceprovider)) {
+                icon = dav.serviceproviders[serviceprovider].icon;
+            }
+            data.setStringValue("tbSyncIcon", "dav" + icon);
+        }
+        return dirPrefId; //change this to data on next big change
     },
 
 
@@ -519,7 +540,7 @@ var dav = {
      *
      * @param account       [in] id of the account which should be searched
      * @param currentQuery  [in] search query
-     * @param caller  [in] "autocomplete" or "search"
+     * @param caller        [in] "autocomplete" or "search"
     
      */
     //abServerSearch: Task.async (function* (account, currentQuery, caller)  {
@@ -528,49 +549,6 @@ var dav = {
 
 
 
-    /**
-     * Is called if one or more cards have been selected in the addressbook, to update
-     * field information in the card view pane
-     *
-     * OPTIONAL, do not implement, if this provider is not adding any fields to the
-     * address book
-     *
-     * @param window       [in] window obj of address book
-     * @param card         [in] selected card
-     */
-    onAbResultsPaneSelectionChanged: function (window, card) {
-        let cvPhMain = window.document.getElementById("cvPhMain");
-        if (cvPhMain) {
-            let cvPhMainValue = card.getProperty("X-DAV-MainPhone","");
-            if (cvPhMainValue) {
-                cvPhMain.textContent = cvPhMain.getAttribute("labelprefix") + " " + cvPhMainValue;
-                cvPhMain.hidden = false;
-                window.document.getElementById("cvbPhone").collapsed = false;
-                window.document.getElementById("cvhPhone").collapsed = false;
-            }
-        }
-    },
-
-
-
-    /**
-     * Is called if a card is loaded in the edit dialog to show/hide elements
-    *  besides those of class type "<provider>Container"
-     *
-     * OPTIONAL, do not implement, if this provider is not manipulating
-     * the edit/new dialog beyond toggeling the elements of
-     * class  "<provider>Container"
-     *
-     * @param document       [in] document obj of edit/new dialog
-     * @param isOwnProvider  [in] true if the open card belongs to this provider
-     */
-    onAbCardLoad: function (document, isOwnProvider) {
-        document.getElementById("WorkAddress2Container").hidden = isOwnProvider;
-        document.getElementById("abHomeTab").children[1].hidden = isOwnProvider;
-    },
-
-
-
     /**
      * Is called if TbSync needs to synchronize an account.
      *
