@@ -53,30 +53,25 @@ dav.sync = {
             unhandledFolders[folders[f].type].push(f);
         }
 
-        let davjobs = {
-            card : {run: true},
-            cal : {run: tbSync.lightningIsAvailable()},        
-        };
-
         //get server urls from account setup - update urls of serviceproviders
         let serviceprovider = tbSync.db.getAccountSetting(syncdata.account, "serviceprovider");
         if (tbSync.dav.serviceproviders.hasOwnProperty(serviceprovider)) {
             tbSync.db.setAccountSetting(syncdata.account, "host", tbSync.dav.serviceproviders[serviceprovider].caldav.replace("https://","").replace("http://",""));
             tbSync.db.setAccountSetting(syncdata.account, "host2", tbSync.dav.serviceproviders[serviceprovider].carddav.replace("https://","").replace("http://",""));
         }
-        davjobs.cal.initialURL = tbSync.db.getAccountSetting(syncdata.account, "host");
-        davjobs.card.initialURL = tbSync.db.getAccountSetting(syncdata.account, "host2");
+
+        let davjobs = {
+            cal : {server: tbSync.db.getAccountSetting(syncdata.account, "host")},
+            card : {server: tbSync.db.getAccountSetting(syncdata.account, "host2")},
+        };
         
         let authenticationManager = Components.classes["@mozilla.org/network/http-auth-manager;1"].getService(Components.interfaces.nsIHttpAuthManager); 
 
         for (let job in davjobs) {
-            if (!davjobs[job].run || !davjobs[job].initialURL) continue;
+            if (!davjobs[job].server) continue;
 
             //clear credential cache, so the Channel will call nsIAuthPrompt2 and expose the realm (caldav and carddav could be on the same host but use different realms, so we reset for each type)
             authenticationManager.clearAll();
-
-            //keep track of the current job
-            syncdata.type = job;
             
             //sync states are only printed while the account state is "syncing" to inform user about sync process (it is not stored in DB, just in syncdata)
             //example state "getfolders" to get folder information from server
@@ -89,12 +84,16 @@ dav.sync = {
 
             tbSync.setSyncState("send.getfolders", syncdata.account);
             {
-                //split initialURL into host and url
-                let parts = davjobs[job].initialURL.split("/").filter(i => i != "");
+                //split server into fqdn and path
+                let parts = davjobs[job].server.split("/").filter(i => i != "");
+
+                //add connection data to syncdata
                 syncdata.fqdn = parts.splice(0,1).toString();
-                let addr = "/" + parts.join("/");                
-                
-                let response = yield dav.tools.sendRequest("<d:propfind "+dav.tools.xmlns(["d"])+"><d:prop><d:current-user-principal /></d:prop></d:propfind>", addr , "PROPFIND", syncdata, {"Depth": "0", "Prefer": "return-minimal"});
+                syncdata.type = job;
+                dav.tools.addAccountDataToConnectionData(syncdata);
+
+                let path = "/" + parts.join("/");                
+                let response = yield dav.tools.sendRequest("<d:propfind "+dav.tools.xmlns(["d"])+"><d:prop><d:current-user-principal /></d:prop></d:propfind>", path , "PROPFIND", syncdata, {"Depth": "0", "Prefer": "return-minimal"});
 
                 tbSync.setSyncState("eval.folders", syncdata.account);
                 if (response && response.multi) principal = dav.tools.getNodeTextContentFromMultiResponse(response, [["d","prop"], ["d","current-user-principal"], ["d","href"]]);
@@ -123,14 +122,18 @@ dav.sync = {
                 //Any groups we need to find? Only diving one level at the moment, 
                 let g = dav.tools.getNodesTextContentFromMultiResponse(response, [["d","prop"], ["d", "group-membership" ], ["d","href"]], principal);
                 for (let gc=0; gc < g.length; gc++) {
-                    response = yield dav.tools.sendRequest(request, g[gc], "PROPFIND", syncdata, {"Depth": "0", "Prefer": "return-minimal"});
+                    //SOGo reports a 403 if I request the provided resource, also since we do not dive, remove the request for group-membership                    
+                    response = yield dav.tools.sendRequest(request.replace("<d:group-membership />",""), g[gc], "PROPFIND", syncdata, {"Depth": "0", "Prefer": "return-minimal"}, {softfail: [403, 404]});
+                    if (response && response.softerror) {
+                        continue;
+                    }		    
                     home = home.concat(dav.tools.getNodesTextContentFromMultiResponse(response, [["d","prop"], [job, homeset ], ["d","href"]], g[gc]));
                 }
 
                 //calendar-proxy and group-membership could have returned the same values, make the homeset unique
                 home = home.filter((v,i,a) => a.indexOf(v) == i);
             } else {
-                throw dav.sync.failed(job+"davservernotfound", davjobs[job].initialURL)
+                throw dav.sync.failed(job+"davservernotfound", davjobs[job].server)
             }
 
             //home now contains something like /remote.php/caldav/calendars/john.bieling/
@@ -143,7 +146,7 @@ dav.sync = {
                                             : "<d:propfind "+dav.tools.xmlns(["d"])+"><d:prop><d:current-user-privilege-set/><d:resourcetype /><d:displayname /></d:prop></d:propfind>";
 
                     //some servers report to have calendar-proxy-read but return a 404 when that gets actually queried
-                    let response = yield dav.tools.sendRequest(request, home[h], "PROPFIND", syncdata, {"Depth": "1", "Prefer": "return-minimal"}, {softfail: [404]});
+                    let response = yield dav.tools.sendRequest(request, home[h], "PROPFIND", syncdata, {"Depth": "1", "Prefer": "return-minimal"}, {softfail: [403, 404]});
                     if (response && response.softerror) {
                         continue;
                     }
@@ -190,7 +193,7 @@ dav.sync = {
                         if (resourcetype == "ics") href =  dav.tools.evaluateNode(response.multi[r].node, [["d","prop"], ["cs","source"], ["d","href"]]).textContent;
                         
                         let name_node = dav.tools.evaluateNode(response.multi[r].node, [["d","prop"], ["d","displayname"]]);
-                        let name = (job == "cal") ? "Calendar" : "Contacts";
+                        let name = tbSync.getLocalizedMessage("defaultname." +  ((job == "cal") ? "calendar" : "contacts") , "dav");
                         if (name_node != null) {
                             name = name_node.textContent;
                         }
@@ -211,6 +214,7 @@ dav.sync = {
                                 
                             newFolder.parentID = "0"; //root - tbsync flatens hierachy, using parentID to sort entries
                             newFolder.selected = "0";
+                            //we assume the folder has the same fqdn as the homeset, otherwise the folderID must contain the full URL and the fqdn is ignored
                             newFolder.fqdn = syncdata.fqdn;
                     
                             //if there is a cached version of this folderID, addFolder will merge all persistent settings - all other settings not defined here will be set to their defaults
@@ -287,11 +291,15 @@ dav.sync = {
                 //all folders of this account have been synced
                 throw dav.sync.succeeded();
             }
+
             //what folder are we syncing?
             syncdata.folderID = nextFolder.folderID;
+            
+            //add connection data to syncdata
             syncdata.type = nextFolder.type;
             syncdata.fqdn = nextFolder.fqdn;
-            
+            dav.tools.addAccountDataToConnectionData(syncdata);
+
             try {
                 switch (syncdata.type) {
                     case "carddav":
@@ -363,7 +371,7 @@ dav.sync = {
     singleFolder: Task.async (function* (syncdata)  {
         syncdata.downloadonly = (tbSync.db.getFolderSetting(syncdata.account, syncdata.folderID, "downloadonly") == "1");
         syncdata.folderCreatedWithProviderVersion = tbSync.db.getFolderSetting(syncdata.account, syncdata.folderID, "createdWithProviderVersion");
-
+        
         yield dav.sync.remoteChanges(syncdata);
         let numOfLocalChanges = yield dav.sync.localChanges(syncdata);
 
@@ -421,7 +429,7 @@ dav.sync = {
 
         let token = tbSync.db.getFolderSetting(syncdata.account, syncdata.folderID, "token");
         tbSync.setSyncState("send.request.remotechanges", syncdata.account, syncdata.folderID);
-        let cards = yield dav.tools.sendRequest("<d:sync-collection "+dav.tools.xmlns(["d"])+"><d:sync-token>"+token+"</d:sync-token><d:sync-level>1</d:sync-level><d:prop><d:getetag/></d:prop></d:sync-collection>", syncdata.folderID, "REPORT", syncdata, {"Content-Type": "application/xml; charset=utf-8"}, {softfail: [415,403]});
+        let cards = yield dav.tools.sendRequest("<d:sync-collection "+dav.tools.xmlns(["d"])+"><d:sync-token>"+token+"</d:sync-token><d:sync-level>1</d:sync-level><d:prop><d:getetag/></d:prop></d:sync-collection>", syncdata.folderID, "REPORT", syncdata, {}, {softfail: [415,403]});
 
         //Sabre\DAV\Exception\ReportNotSupported - Unsupported media type - returned by fruux if synctoken is 0 (empty book), 415 & 403
         //https://github.com/sabre-io/dav/issues/1075
@@ -447,9 +455,8 @@ dav.sync = {
             let id = cards.multi[c].href;
             if (id !==null) {
                 //valid
-                let status = cards.multi[c].status;
                 let card = tbSync.getCardFromProperty(addressBook, "TBSYNCID", id);
-                if (status == "200") {
+                if (cards.multi[c].status == "200") {
                     //MOD or ADD
                     let etag = dav.tools.evaluateNode(cards.multi[c].node, [["d","prop"], ["d","getetag"]]);
                     if (!card) {
@@ -462,11 +469,14 @@ dav.sync = {
                         syncdata.todo++;
                         vCardsChangedOnServer[id] = "MOD"; 
                     }
-                } else if (status == "404" && card) {
+                } else if (cards.multi[c].responsestatus == "404" && card) {
                     //DEL
                     syncdata.todo++;
                     vCardsDeletedOnServer.appendElement(card, false);
                     tbSync.db.addItemToChangeLog(syncdata.targetId, id, "deleted_by_server");
+                } else {
+                    //We received something, that is not a DEL, MOD or ADD
+                    tbSync.errorlog("warning", syncdata, "Unknown XML", JSON.stringify(cards.multi[c]));
                 }
             }
         }
@@ -595,7 +605,7 @@ dav.sync = {
             let request = dav.tools.getMultiGetRequest(cards2catch.slice(i, i+maxitems));
             if (request) {
                 tbSync.setSyncState("send.request.remotechanges", syncdata.account, syncdata.folderID);
-                let cards = yield dav.tools.sendRequest(request, syncdata.folderID, "REPORT", syncdata, {"Depth": "1", "Content-Type": "application/xml; charset=utf-8"});
+                let cards = yield dav.tools.sendRequest(request, syncdata.folderID, "REPORT", syncdata, {"Depth": "1"});
 
                 tbSync.setSyncState("eval.response.remotechanges", syncdata.account, syncdata.folderID);
                 for (let c=0; c < cards.multi.length; c++) {
@@ -614,6 +624,9 @@ dav.sync = {
                                 dav.tools.modifyContact (addressBook, id, data, etag, syncdata);
                                 break;
                         }
+                        //Feedback from users: They want to see the individual count
+                        tbSync.setSyncState("eval.response.remotechanges", syncdata.account, syncdata.folderID);		
+                        yield tbSync.sleep(100, false);
                     } else {
                         tbSync.dump("Skipped Card", [id, cards.multi[c].status == "200", etag !== null, data !== null, id !== null, vCardsChangedOnServer.hasOwnProperty(id)].join(", "));
                     }
@@ -621,8 +634,8 @@ dav.sync = {
             }
         }
         //Feedback from users: They want to see the final count
-        tbSync.setSyncState("eval.request.remotechanges", syncdata.account, syncdata.folderID);		
-        yield tbSync.sleep(100, false);
+        tbSync.setSyncState("eval.response.remotechanges", syncdata.account, syncdata.folderID);		
+        yield tbSync.sleep(200, false);
     
         let syncGroups = (tbSync.db.getAccountSetting(syncdata.account, "syncGroups") == "1");
         if (syncGroups) {
@@ -674,7 +687,9 @@ dav.sync = {
                                     //fix for bug 1522453
                                     let email = card.getProperty("PrimaryEmail", "");
                                     if (!email) {
-                                        card.setProperty("PrimaryEmail", Date.now() + "." +listcount + "." + i + "@bug1522453");
+                                        let email = Date.now() + "." +listcount + "." + i + "@bug1522453";
+                                        card.setProperty("PrimaryEmail", email);
+                                        card.setProperty("X-DAV-JSON-Emails", JSON.stringify([{meta: [], value: email}]));
                                         addressBook.modifyCard(card);
                                     }
                                     mailListDirectory.addressLists.appendElement(card, false);
@@ -819,12 +834,14 @@ dav.sync = {
                         {
                             if (!permissionError[changes[i].status]) { //if this operation failed already, do not retry
                                 tbSync.setSyncState("send.request.localchanges", syncdata.account, syncdata.folderID);
-                                let response = yield dav.tools.sendRequest("", changes[i].id , "DELETE", syncdata, {}, {softfail: [403, 405]});
+                                let response = yield dav.tools.sendRequest("", changes[i].id , "DELETE", syncdata, {}, {softfail: [403, 404, 405]});
 
                                 tbSync.setSyncState("eval.response.localchanges", syncdata.account, syncdata.folderID);
                                 if (response  && response.softerror) {
-                                    permissionError[changes[i].status] = true;
-                                    tbSync.errorlog("warning", syncdata, "missing-permission::" + tbSync.getLocalizedMessage("acl.delete", "dav"));
+                                    if (response.softerror != 404) { //we cannot do anything about a 404 on delete, the card has been deleted here and is not avail on server
+                                        permissionError[changes[i].status] = true;
+                                        tbSync.errorlog("warning", syncdata, "missing-permission::" + tbSync.getLocalizedMessage("acl.delete", "dav"));
+                                    }
                                 }
                             }
 
